@@ -6,13 +6,11 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_ACTIONS_H
-#define AKREGATOR_ACTIONS_H
+#pragma once
 
 #include "akregator_export.h"
 #include <QObject>
 class QAction;
-class QObject;
 
 class QUrl;
 
@@ -22,4 +20,3 @@ AKREGATOR_EXPORT QAction *createOpenLinkInNewTabAction(const QUrl &url, QObject
 AKREGATOR_EXPORT QAction *createOpenLinkInExternalBrowserAction(const QUrl &url, QObject *parent = nullptr);
 }
 
-#endif // AKREGATOR_ACTIONS_H
