@@ -9,8 +9,8 @@
 #include "mainwindow.h"
 #include "akregator_part.h"
 #include "akregatorconfig.h"
+#include "kcoreaddons_version.h"
 #include "trayicon.h"
-
 #include <Libkdepim/ProgressStatusBarWidget>
 #include <Libkdepim/StatusbarProgressWidget>
 #include <PimCommon/BroadcastStatus>
@@ -21,7 +21,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPluginFactory>
-#include <KPluginLoader>
+#include <KPluginMetaData>
 #include <KSharedConfig>
 #include <KShortcutsDialog>
 #include <KSqueezedTextLabel>
@@ -58,7 +58,9 @@ MainWindow::MainWindow(QWidget *parent)
     statusBar()->addWidget(m_statusLabel, 1);
 
     KStandardAction::quit(qApp, &QApplication::quit, actionCollection());
-    mShowMenuBarAction = KStandardAction::showMenubar(menuBar(), &QMenuBar::setVisible, actionCollection());
+    mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
+    mShowMenuBarAction->setChecked(Settings::showMenuBar());
+    slotToggleMenubar(true);
 
     if (menuBar()) {
         mHamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, actionCollection());
@@ -81,6 +83,27 @@ MainWindow::MainWindow(QWidget *parent)
     connect(qApp, &QCoreApplication::aboutToQuit, this, &MainWindow::slotOnShutdown);
 }
 
+void MainWindow::slotToggleMenubar(bool dontShowWarning)
+{
+    if (menuBar()) {
+        if (mShowMenuBarAction->isChecked()) {
+            menuBar()->show();
+        } else {
+            if (!dontShowWarning && (!toolBar()->isVisible() || !toolBar()->actions().contains(mHamburgerMenu))) {
+                const QString accel = mShowMenuBarAction->shortcut().toString();
+                KMessageBox::information(this,
+                                         i18n("<qt>This will hide the menu bar completely."
+                                              " You can show it again by typing %1.</qt>",
+                                              accel),
+                                         i18n("Hide menu bar"),
+                                         QStringLiteral("HideMenuBarWarning"));
+            }
+            menuBar()->hide();
+        }
+        Settings::setShowMenuBar(mShowMenuBarAction->isChecked());
+    }
+}
+
 void MainWindow::updateHamburgerMenu()
 {
     QMenu *menu = new QMenu(this);
@@ -96,16 +119,12 @@ bool MainWindow::loadPart()
     // this routine will find and load our Part.  it finds the Part by
     // name which is a bad idea usually.. but it's alright in this
     // case since our Part is made for this Shell
-    KPluginLoader loader(QStringLiteral("akregatorpart"));
-    KPluginFactory *const factory = loader.factory();
-    if (!factory) {
-        KMessageBox::error(this, i18n("Could not find the Akregator part; please check your installation.\n%1", loader.errorString()));
-        return false;
-    }
-
-    m_part = static_cast<Akregator::Part *>(factory->create<KParts::Part>(this));
-
-    if (!m_part) {
+    const KPluginMetaData md(QStringLiteral("akregatorpart"));
+    const auto result = KPluginFactory::instantiatePlugin<KParts::Part>(md, this);
+    if (result) {
+        m_part = static_cast<Akregator::Part *>(result.plugin);
+    } else {
+        KMessageBox::error(this, i18n("Could not find the Akregator part; please check your installation.\n%1", result.errorString));
         return false;
     }
 
@@ -155,7 +174,7 @@ void MainWindow::readProperties(const KConfigGroup &config)
 // TODO: move to part?
 void MainWindow::optionsConfigureKeys()
 {
-    KShortcutsDialog dlg(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
+    KShortcutsDialog dlg(this);
 
     dlg.addCollection(actionCollection());
     if (m_part) {
