@@ -5,8 +5,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef AKREGATOR_SELECTIONCONTROLLER_H
-#define AKREGATOR_SELECTIONCONTROLLER_H
+#pragma once
 
 #include "abstractselectioncontroller.h"
 
@@ -92,4 +91,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_SELECTIONCONTROLLER_H
